pub fn primary_chunkable_referenced_modules(
module: Vc<Box<dyn Module>>,
include_traced: bool,
include_binding_usage: bool,
) -> Vc<ModulesWithRefData>Expand description
Aggregates all primary Modules referenced by an Module via ModuleReferences with a non-empty chunking_type. This does not include transitively referenced Modules, only primary Modules referenced.