DynamicTraceReference

Trait DynamicTraceReference 

pub trait DynamicTraceReference:
    ModuleReference
    + Send
    + Sync
    + NonLocalValue
    + ValueDebug {
    // Required method
    fn origin_fn_name(&self) -> RcStr;
}
A ModuleReference created by tracing a dynamic filesystem access (e.g. fs.readFileSync, path.join) for the purpose of Node File Tracing.

Required Methods

fn origin_fn_name(&self) -> RcStr

The name of the function/call that created this reference (e.g. fs.readFileSync). Used to name the offending call in tracing diagnostics so the suggested fix refers to the actual call rather than an example.